package VMOMI::ClusterVmComponentProtectionSettingsVmReactionOnAPDCleared;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
